@@ -66,7 +66,7 @@ typedef enum {
 
 #if (!PK_CHECK_VERSION(0,6,2))
 #define PK_CLIENT_ERROR_DECLINED_SIMULATION				 PK_CLIENT_ERROR_FAILED
-#define PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED				 PK_ERROR_ENUM_ENUM_LAST
+#define PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED				 PK_ERROR_ENUM_LAST
 #define PK_CLIENT_ERROR_LAST						(PK_CLIENT_ERROR_DECLINED_SIMULATION + 1)
 #endif
 
@@ -84,8 +84,6 @@ const gchar	*gpk_role_enum_to_localised_past	(PkRoleEnum	 role)
 							 G_GNUC_CONST;
 const gchar	*gpk_role_enum_to_localised_present	(PkRoleEnum	 role)
 							 G_GNUC_CONST;
-GpkUpdateEnum	 gpk_update_enum_from_text		(const gchar	*update);
-const gchar	*gpk_update_enum_to_text		(GpkUpdateEnum	 update);
 const gchar	*gpk_role_enum_to_icon_name		(PkRoleEnum	 role);
 const gchar	*gpk_media_type_enum_to_localised_text	(PkMediaTypeEnum type)
 							 G_GNUC_CONST;
